@@ -1,6 +1,7 @@
 package app
 
 import (
+	"github.com/livebud/bud/framework"
 	"github.com/livebud/bud/internal/imports"
 	"github.com/livebud/bud/package/di"
 )
@@ -8,4 +9,5 @@ import (
 type State struct {
 	Imports  []*imports.Import
 	Provider *di.Provider
+	Flag     *framework.Flag
 }
