@@ -3,8 +3,11 @@ package controller_test
 import (
 	"bytes"
 	"context"
+	"os"
+	"path/filepath"
 	"testing"
 
+	"github.com/lithammer/dedent"
 	"github.com/livebud/bud/internal/cli/testcli"
 	"github.com/livebud/bud/internal/is"
 	"github.com/livebud/bud/internal/testdir"
@@ -724,9 +727,10 @@ func TestJSONDelete500(t *testing.T) {
 	td.Files["controller/controller.go"] = `
 		package controller
 		import "errors"
+		import "context"
 		type Controller struct {}
-		func (c *Controller) Delete() (string, error) {
-			return "", errors.New("Not implemented yet")
+		func (c *Controller) Delete(ctx context.Context, id int) (err error) {
+			return errors.New("Not implemented yet")
 		}
 	`
 	is.NoErr(td.Write(ctx))
@@ -1772,16 +1776,16 @@ func TestOkChangeOk(t *testing.T) {
 		Content-Type: text/html
 	`))
 	is.In(res.Body().String(), `Hello Users!`)
-	// Update file
-	td = testdir.New(dir)
-	td.Files["controller/controller.go"] = `
+	// Update controller
+	controllerFile := filepath.Join(dir, "controller", "controller.go")
+	is.NoErr(os.MkdirAll(filepath.Dir(controllerFile), 0755))
+	is.NoErr(os.WriteFile(controllerFile, []byte(dedent.Dedent(`
 		package controller
 		type Controller struct {}
 		func (c *Controller) Index() string {
 			return "Hello Humans!"
 		}
-	`
-	is.NoErr(td.Write(ctx))
+	`)), 0644))
 	is.NoErr(app.Ready(ctx))
 	// Try again with the new file
 	res, err = app.Get("/")
@@ -2061,13 +2065,15 @@ func TestControllerChange(t *testing.T) {
 
 		"/"
 	`)
-	// Update file
-	td.Files["controller/controller.go"] = `
+	// Update controller
+	controllerFile := filepath.Join(dir, "controller", "controller.go")
+	is.NoErr(os.MkdirAll(filepath.Dir(controllerFile), 0755))
+	is.NoErr(os.WriteFile(controllerFile, []byte(dedent.Dedent(`
 		package controller
 		type Controller struct {}
 		func (c *Controller) Index() string { return "/" }
-	`
-	is.NoErr(td.Write(ctx))
+	`)), 0644))
+	// Wait for the app to be ready again
 	is.NoErr(app.Ready(ctx))
 	// Try again with the new file
 	res, err = app.GetJSON("/")
@@ -2361,3 +2367,428 @@ func TestInject(t *testing.T) {
 		1
 	`))
 }
+
+func TestEscapeProps(t *testing.T) {
+	is := is.New(t)
+	ctx := context.Background()
+	dir := t.TempDir()
+	td := testdir.New(dir)
+	td.NodeModules["svelte"] = versions.Svelte
+	td.Files["controller/controller.go"] = `
+		package controller
+		type Controller struct {}
+		type Post struct {
+			HTML string ` + "`json:\"html\"`" + `
+		}
+		func (c *Controller) Show(id string) *Post {
+			return &Post{HTML: ` + "`" + `<b>hello ` + "`" + ` + id + ` + "`" + `<script type="text/javascript">alert('xss!')</script></b>` + "`" + `}
+		}
+	`
+	td.Files["view/show.svelte"] = `
+		<script>
+			export let post = {}
+		</script>
+		<h1>{post.html}</h1>
+	`
+	is.NoErr(td.Write(ctx))
+	cli := testcli.New(dir)
+	app, err := cli.Start(ctx, "run")
+	is.NoErr(err)
+	defer app.Close()
+	// Post request
+	res, err := app.Get("/alice")
+	is.NoErr(err)
+	props, err := res.Query("#bud_props")
+	is.NoErr(err)
+	is.Equal(props.Text(), `{"post":{"html":"<b>hello alice<script type=\"text/javascript\">alert('xss!')<\/script></b>"}}`)
+	target, err := res.Query("#bud_target")
+	is.NoErr(err)
+	is.Equal(target.Text(), `<b>hello alice<script type="text/javascript">alert('xss!')</script></b>`)
+}
+
+func TestProtocol(t *testing.T) {
+	is := is.New(t)
+	ctx := context.Background()
+	dir := t.TempDir()
+	td := testdir.New(dir)
+	td.NodeModules["svelte"] = versions.Svelte
+	td.NodeModules["livebud"] = "*"
+	td.Files["model/model.go"] = `
+		package model
+		type MyArticle struct {
+			SlugID string
+		}
+	`
+	td.Files["controller/controller.go"] = `
+		package controller
+		import "app.com/model"
+		type Controller struct {}
+		type MyPost struct {
+			ID string ` + "`" + `json:"id"` + "`" + `
+		}
+		func (c *Controller) Index() string { return "index" }
+		func (c *Controller) IndexErr() (string, error) { return "index_err", nil }
+		func (c *Controller) Named() (name string) { return "named" }
+		func (c *Controller) NamedErr() (name string, err error) { return "named_err", nil }
+		func (c *Controller) Post() *MyPost { return &MyPost{ID:"post"} }
+		func (c *Controller) PostErr() (*MyPost, error) { return &MyPost{ID:"post_err"}, nil }
+		func (c *Controller) NamedPost() (post *MyPost) { return &MyPost{ID:"named_post"} }
+		func (c *Controller) NamedPostErr() (post *MyPost, err error) { return &MyPost{ID:"named_post_err"}, nil }
+		func (c *Controller) Article() *model.MyArticle { return &model.MyArticle{SlugID:"article"} }
+		func (c *Controller) ArticleErr() (*model.MyArticle, error) { return &model.MyArticle{SlugID:"article_err"}, nil }
+		func (c *Controller) NamedArticle() (article *model.MyArticle) { return &model.MyArticle{SlugID:"named_article"} }
+		func (c *Controller) NamedArticleErr() (article *model.MyArticle, err error) { return &model.MyArticle{SlugID:"named_article_err"}, nil }
+	`
+	td.Files["view/index.svelte"] = `
+		<script>
+			export let _string = ""
+		</script>
+		<h1>{_string}</h1>
+	`
+	td.Files["view/index_err.svelte"] = `
+		<script>
+			export let _string = ""
+		</script>
+		<h1>{_string}</h1>
+	`
+	td.Files["view/named.svelte"] = `
+		<script>
+			export let name = ""
+		</script>
+		<h1>{name}</h1>
+	`
+	td.Files["view/named_err.svelte"] = `
+		<script>
+			export let name = ""
+		</script>
+		<h1>{name}</h1>
+	`
+	td.Files["view/post.svelte"] = `
+		<script>
+			export let myPost = {}
+		</script>
+		<h1>{myPost.id}</h1>
+	`
+	td.Files["view/post_err.svelte"] = `
+		<script>
+		export let myPost = {}
+		</script>
+		<h1>{myPost.id}</h1>
+	`
+	td.Files["view/named_post.svelte"] = `
+		<script>
+			export let post = {}
+		</script>
+		<h1>{post.id}</h1>
+	`
+	td.Files["view/named_post_err.svelte"] = `
+		<script>
+		export let post = {}
+		</script>
+		<h1>{post.id}</h1>
+	`
+	td.Files["view/article.svelte"] = `
+		<script>
+			export let myArticle = {}
+		</script>
+		<h1>{myArticle.SlugID}</h1>
+	`
+	td.Files["view/article_err.svelte"] = `
+		<script>
+		export let myArticle = {}
+		</script>
+		<h1>{myArticle.SlugID}</h1>
+	`
+	td.Files["view/named_article.svelte"] = `
+		<script>
+			export let article = {}
+		</script>
+		<h1>{article.SlugID}</h1>
+	`
+	td.Files["view/named_article_err.svelte"] = `
+		<script>
+		export let article = {}
+		</script>
+		<h1>{article.SlugID}</h1>
+	`
+	is.NoErr(td.Write(ctx))
+	cli := testcli.New(dir)
+	app, err := cli.Start(ctx, "run")
+	is.NoErr(err)
+	defer app.Close()
+	// index
+	res, err := app.GetJSON("/")
+	is.NoErr(err)
+	is.NoErr(res.Diff(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+
+		"index"
+	`))
+	res, err = app.Get("/")
+	is.NoErr(err)
+	sel, err := res.Query("#bud_target")
+	is.NoErr(err)
+	html, err := sel.Html()
+	is.NoErr(err)
+	is.Equal(html, `<h1>index</h1>`)
+	// index error
+	res, err = app.GetJSON("/index_err")
+	is.NoErr(err)
+	is.NoErr(res.Diff(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+
+		"index_err"
+	`))
+	res, err = app.Get("/index_err")
+	is.NoErr(err)
+	is.Equal(res.Status(), 200)
+	sel, err = res.Query("#bud_target")
+	is.NoErr(err)
+	html, err = sel.Html()
+	is.NoErr(err)
+	is.Equal(html, `<h1>index_err</h1>`)
+	// named
+	res, err = app.GetJSON("/named")
+	is.NoErr(err)
+	is.NoErr(res.Diff(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+
+		"named"
+	`))
+	res, err = app.Get("/named")
+	is.NoErr(err)
+	sel, err = res.Query("#bud_target")
+	is.NoErr(err)
+	html, err = sel.Html()
+	is.NoErr(err)
+	is.Equal(html, `<h1>named</h1>`)
+	// named err
+	res, err = app.GetJSON("/named_err")
+	is.NoErr(err)
+	is.NoErr(res.Diff(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+
+		"named_err"
+	`))
+	res, err = app.Get("/named_err")
+	is.NoErr(err)
+	sel, err = res.Query("#bud_target")
+	is.NoErr(err)
+	html, err = sel.Html()
+	is.NoErr(err)
+	is.Equal(html, `<h1>named_err</h1>`)
+	// post
+	res, err = app.GetJSON("/post")
+	is.NoErr(err)
+	is.NoErr(res.Diff(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+
+		{"id":"post"}
+	`))
+	res, err = app.Get("/post")
+	is.NoErr(err)
+	sel, err = res.Query("#bud_target")
+	is.NoErr(err)
+	html, err = sel.Html()
+	is.NoErr(err)
+	is.Equal(html, `<h1>post</h1>`)
+	// post err
+	res, err = app.GetJSON("/post_err")
+	is.NoErr(err)
+	is.NoErr(res.Diff(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+
+		{"id":"post_err"}
+	`))
+	res, err = app.Get("/post_err")
+	is.NoErr(err)
+	sel, err = res.Query("#bud_target")
+	is.NoErr(err)
+	html, err = sel.Html()
+	is.NoErr(err)
+	is.Equal(html, `<h1>post_err</h1>`)
+	// named post
+	res, err = app.GetJSON("/named_post")
+	is.NoErr(err)
+	is.NoErr(res.Diff(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+
+		{"id":"named_post"}
+	`))
+	res, err = app.Get("/named_post")
+	is.NoErr(err)
+	sel, err = res.Query("#bud_target")
+	is.NoErr(err)
+	html, err = sel.Html()
+	is.NoErr(err)
+	is.Equal(html, `<h1>named_post</h1>`)
+	// named post err
+	res, err = app.GetJSON("/named_post_err")
+	is.NoErr(err)
+	is.NoErr(res.Diff(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+
+		{"id":"named_post_err"}
+	`))
+	res, err = app.Get("/named_post_err")
+	is.NoErr(err)
+	sel, err = res.Query("#bud_target")
+	is.NoErr(err)
+	html, err = sel.Html()
+	is.NoErr(err)
+	is.Equal(html, `<h1>named_post_err</h1>`)
+	// article
+	res, err = app.GetJSON("/article")
+	is.NoErr(err)
+	is.NoErr(res.Diff(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+
+		{"SlugID":"article"}
+	`))
+	res, err = app.Get("/article")
+	is.NoErr(err)
+	sel, err = res.Query("#bud_target")
+	is.NoErr(err)
+	html, err = sel.Html()
+	is.NoErr(err)
+	is.Equal(html, `<h1>article</h1>`)
+	// article err
+	res, err = app.GetJSON("/article_err")
+	is.NoErr(err)
+	is.NoErr(res.Diff(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+
+		{"SlugID":"article_err"}
+	`))
+	res, err = app.Get("/article_err")
+	is.NoErr(err)
+	sel, err = res.Query("#bud_target")
+	is.NoErr(err)
+	html, err = sel.Html()
+	is.NoErr(err)
+	is.Equal(html, `<h1>article_err</h1>`)
+	// named article
+	res, err = app.GetJSON("/named_article")
+	is.NoErr(err)
+	is.NoErr(res.Diff(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+
+		{"SlugID":"named_article"}
+	`))
+	res, err = app.Get("/named_article")
+	is.NoErr(err)
+	sel, err = res.Query("#bud_target")
+	is.NoErr(err)
+	html, err = sel.Html()
+	is.NoErr(err)
+	is.Equal(html, `<h1>named_article</h1>`)
+	// named article err
+	res, err = app.GetJSON("/named_article_err")
+	is.NoErr(err)
+	is.NoErr(res.Diff(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+
+		{"SlugID":"named_article_err"}
+	`))
+	res, err = app.Get("/named_article_err")
+	is.NoErr(err)
+	sel, err = res.Query("#bud_target")
+	is.NoErr(err)
+	html, err = sel.Html()
+	is.NoErr(err)
+	is.Equal(html, `<h1>named_article_err</h1>`)
+	// close the app
+	is.NoErr(app.Close())
+}
+
+// Asserts that a root index action is compatible with an index
+// controller. Also asserts that a posts index action is compatible
+// with a posts/index controller.
+func TestIndexControllerWithRootIndexAction(t *testing.T) {
+	is := is.New(t)
+	ctx := context.Background()
+	dir := t.TempDir()
+	td := testdir.New(dir)
+	// root controller with index action
+	td.Files["controller/controller.go"] = `
+		package controller
+		type Controller struct{}
+		func (c *Controller) Index() []string {
+			return []string{}
+		}
+	`
+	// index controller with index action
+	td.Files["controller/index/controller.go"] = `
+		package index
+		type Controller struct{}
+		func (c *Controller) Index() []string {
+			return []string{}
+		}
+	`
+	// posts controller with index action
+	td.Files["controller/posts/controller.go"] = `
+		package posts
+		type Controller struct{}
+		func (c *Controller) Index() []string {
+			return []string{}
+		}
+	`
+	// posts/index controller with index action
+	td.Files["controller/posts/index/controller.go"] = `
+		package index
+		type Controller struct{}
+		func (c *Controller) Index() []string {
+			return []string{}
+		}
+	`
+	is.NoErr(td.Write(ctx))
+	cli := testcli.New(dir)
+	app, err := cli.Start(ctx, "run")
+	is.NoErr(err)
+	defer app.Close()
+	res, err := app.GetJSON("/")
+	is.NoErr(err)
+	is.NoErr(res.Diff(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+
+		[]
+	`))
+	res, err = app.GetJSON("/index")
+	is.NoErr(err)
+	is.NoErr(res.Diff(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+
+		[]
+	`))
+	res, err = app.GetJSON("/posts")
+	is.NoErr(err)
+	is.NoErr(res.Diff(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+
+		[]
+	`))
+	res, err = app.GetJSON("/posts/1/index")
+	is.NoErr(err)
+	is.NoErr(res.Diff(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+
+		[]
+	`))
+	is.NoErr(app.Close())
+}
