@@ -3,9 +3,12 @@ package view_test
 import (
 	"context"
 	"fmt"
+	"os"
+	"path/filepath"
 	"regexp"
 	"testing"
 
+	"github.com/lithammer/dedent"
 	"github.com/livebud/bud/internal/cli/testcli"
 	"github.com/livebud/bud/internal/is"
 	"github.com/livebud/bud/internal/testdir"
@@ -43,9 +46,9 @@ func TestHello(t *testing.T) {
 	is.In(res.Body().String(), "<h1>hello</h1>")
 	is.NoErr(td.Exists("bud/internal/app/view/view.go"))
 	// Change svelte file
-	td = testdir.New(dir)
-	td.Files["view/index.svelte"] = `<h1>hi</h1>`
-	is.NoErr(td.Write(ctx))
+	indexFile := filepath.Join(dir, "view/index.svelte")
+	is.NoErr(os.MkdirAll(filepath.Dir(indexFile), 0755))
+	is.NoErr(os.WriteFile(indexFile, []byte(`<h1>hi</h1>`), 0644))
 	// Wait for the app to be ready again
 	app.Ready(ctx)
 	// Check that we received a hot reload event
@@ -94,9 +97,9 @@ func TestHelloEmbed(t *testing.T) {
 	`))
 	is.In(res.Body().String(), "<h1>hello</h1>")
 	// Change svelte file
-	td = testdir.New(dir)
-	td.Files["view/index.svelte"] = `<h1>hi</h1>`
-	is.NoErr(td.Write(ctx))
+	indexFile := filepath.Join(dir, "view/index.svelte")
+	is.NoErr(os.MkdirAll(filepath.Dir(indexFile), 0755))
+	is.NoErr(os.WriteFile(indexFile, []byte(`<h1>hi</h1>`), 0644))
 	// Wait for the the app to be ready again
 	is.NoErr(app.Ready(ctx))
 	// Ensure that we got a hot reload event
@@ -245,3 +248,146 @@ func TestConsoleError(t *testing.T) {
 	// https://github.com/kuoruan/v8go-polyfills
 	t.SkipNow()
 }
+
+func TestRenameView(t *testing.T) {
+	is := is.New(t)
+	ctx := context.Background()
+	dir := t.TempDir()
+	td := testdir.New(dir)
+	td.Files["controller/controller.go"] = `
+		package controller
+		type Controller struct {}
+		func (c *Controller) Show() (id int) { return 10 }
+	`
+	td.Files["view/show.svelte"] = `
+		<script>
+			export let id = 0
+		</script>
+		<h1>{id}</h1>
+	`
+	td.NodeModules["svelte"] = versions.Svelte
+	td.NodeModules["livebud"] = "*"
+	is.NoErr(td.Write(ctx))
+	cli := testcli.New(dir)
+	app, err := cli.Start(ctx, "run")
+	is.NoErr(err)
+	defer app.Close()
+	hot, err := app.Hot("/bud/hot/view/show.svelte")
+	is.NoErr(err)
+	defer hot.Close()
+	res, err := app.Get("/10")
+	is.NoErr(err)
+	is.NoErr(res.DiffHeaders(`
+		HTTP/1.1 200 OK
+		Transfer-Encoding: chunked
+		Content-Type: text/html
+	`))
+	is.In(res.Body().String(), "<h1>10</h1>")
+	// Rename the file
+	is.NoErr(os.Rename(
+		filepath.Join(dir, "view/show.svelte"),
+		filepath.Join(dir, "view/_show.svele"),
+	))
+	// Wait for the app to be ready again
+	app.Ready(ctx)
+	// Check that we received a hot reload event
+	event, err := hot.Next(ctx)
+	is.NoErr(err)
+	is.In(string(event.Data), `{"reload":true}`)
+	// Should change
+	res, err = app.Get("/10")
+	is.NoErr(err)
+	is.NoErr(res.DiffHeaders(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+	`))
+	is.Equal(res.Body().String(), "10")
+	is.NoErr(app.Close())
+}
+
+func TestAddView(t *testing.T) {
+	is := is.New(t)
+	ctx := context.Background()
+	dir := t.TempDir()
+	td := testdir.New(dir)
+	td.Files["controller/controller.go"] = `
+		package controller
+		type Controller struct {}
+		func (c *Controller) Show() (id int) { return 10 }
+	`
+	td.NodeModules["svelte"] = versions.Svelte
+	td.NodeModules["livebud"] = "*"
+	is.NoErr(td.Write(ctx))
+	cli := testcli.New(dir)
+	app, err := cli.Start(ctx, "run")
+	is.NoErr(err)
+	defer app.Close()
+	hot, err := app.Hot("/bud/hot/view/show.svelte")
+	is.NoErr(err)
+	defer hot.Close()
+	res, err := app.Get("/10")
+	is.NoErr(err)
+	is.NoErr(res.DiffHeaders(`
+		HTTP/1.1 200 OK
+		Content-Type: application/json
+	`))
+	is.Equal(res.Body().String(), "10")
+	// Add the view
+	showView := filepath.Join(dir, "view/show.svelte")
+	is.NoErr(os.MkdirAll(filepath.Dir(showView), 0755))
+	is.NoErr(os.WriteFile(showView, []byte(dedent.Dedent(`
+		<script>
+			export let id = 0
+		</script>
+		<h1>{id}</h1>
+	`)), 0644))
+	// Wait for the app to be ready again
+	app.Ready(ctx)
+	// Check that we received a hot reload event
+	event, err := hot.Next(ctx)
+	is.NoErr(err)
+	is.In(string(event.Data), `{"reload":true}`)
+	// Should change
+	res, err = app.Get("/10")
+	is.NoErr(err)
+	is.NoErr(res.DiffHeaders(`
+		HTTP/1.1 200 OK
+		Transfer-Encoding: chunked
+		Content-Type: text/html
+	`))
+	is.In(res.Body().String(), "<h1>10</h1>")
+}
+
+func TestSvelteImportFromNodeModule(t *testing.T) {
+	is := is.New(t)
+	ctx := context.Background()
+	dir := t.TempDir()
+	td := testdir.New(dir)
+	td.NodeModules["svelte"] = versions.Svelte
+	td.NodeModules["svelte-time"] = "*"
+	td.Files["controller/controller.go"] = `
+		package controller
+		type Controller struct {}
+		func (c *Controller) Index() string { return "" }
+	`
+	td.Files["view/index.svelte"] = `
+		<script>
+			import Time from 'svelte-time';
+		</script>
+		<p>The time is <Time timestamp="2022-07-19 10:19:00" />.</p>
+	`
+	is.NoErr(td.Write(ctx))
+	cli := testcli.New(dir)
+	app, err := cli.Start(ctx, "run")
+	is.NoErr(err)
+	defer app.Close()
+	res, err := app.Get("/")
+	is.NoErr(err)
+	is.NoErr(res.DiffHeaders(`
+		HTTP/1.1 200 OK
+		Transfer-Encoding: chunked
+		Content-Type: text/html
+	`))
+	is.In(res.Body().String(), "<time datetime=\"2022-07-19 10:19:00\">Jul 19, 2022</time>")
+	is.NoErr(app.Close())
+}
