@@ -1,7 +1,10 @@
 package create_test
 
 import (
+	"bufio"
 	"context"
+	"os"
+	"path/filepath"
 	"testing"
 
 	"github.com/livebud/bud/internal/cli/testcli"
@@ -10,7 +13,15 @@ import (
 	"golang.org/x/mod/modfile"
 )
 
-func TestCreateOutsideGoPathError(t *testing.T) {
+func fileFirstLine(filePath string) string {
+	file, _ := os.Open(filePath)
+	defer file.Close()
+	scanner := bufio.NewReader(file)
+	line, _ := scanner.ReadString('\n')
+	return line
+}
+
+func TestCreateOutsideGoPath(t *testing.T) {
 	is := is.New(t)
 	ctx := context.Background()
 	dir := t.TempDir()
@@ -20,10 +31,14 @@ func TestCreateOutsideGoPathError(t *testing.T) {
 	cli := testcli.New(dir)
 	is.NoErr(td.NotExists(".gitignore"))
 	result, err := cli.Run(ctx, "create", dir)
-	is.In(err.Error(), `Try again using the module <path> name.`)
+	is.NoErr(err)
 	is.Equal(result.Stdout(), "")
 	is.Equal(result.Stderr(), "")
-	is.NoErr(td.NotExists(".gitignore"))
+	is.Equal(fileFirstLine(filepath.Join(dir, "go.mod")), "module change.me\n")
+	is.NoErr(td.Exists(".gitignore"))
+	is.NoErr(td.Exists("go.sum"))
+	is.NoErr(td.Exists("package.json"))
+	is.NoErr(td.Exists("package-lock.json"))
 }
 
 func TestCreateOutsideGoPathModulePath(t *testing.T) {
@@ -37,6 +52,7 @@ func TestCreateOutsideGoPathModulePath(t *testing.T) {
 	is.NoErr(err)
 	is.Equal(result.Stdout(), "")
 	is.Equal(result.Stderr(), "")
+	is.Equal(fileFirstLine(filepath.Join(dir, "go.mod")), "module github.com/my/app\n")
 	is.NoErr(td.Exists(".gitignore"))
 	is.NoErr(td.Exists("go.sum"))
 	is.NoErr(td.Exists("package.json"))
