@@ -32,15 +32,16 @@ func (c *Command) Run(ctx context.Context) error {
 	if err != nil {
 		return err
 	}
-	module, err := bud.Module(c.Dir)
-	if err != nil {
-		return err
-	}
-	fsys, err := bud.FileSystem(log, module, c.Flag)
-	if err != nil {
-		return err
-	}
 	dir := path.Clean(c.Dir)
+	module, err := bud.Module(path.Join(c.bud.Dir, dir))
+	if err != nil {
+		return err
+	}
+	fsys, close, err := bud.FileSystem(ctx, log, module, c.Flag, c.in)
+	if err != nil {
+		return err
+	}
+	defer close()
 	des, err := fs.ReadDir(fsys, dir)
 	if err != nil {
 		return err
