@@ -33,16 +33,17 @@ func (c *Command) Run(ctx context.Context) error {
 	if err != nil {
 		return err
 	}
-	module, err := bud.Module(c.Dir)
-	if err != nil {
-		return err
-	}
-	fsys, err := bud.FileSystem(log, module, c.Flag)
-	if err != nil {
-		return err
-	}
-	ar := new(txtar.Archive)
 	dir := path.Clean(c.Dir)
+	module, err := bud.Module(path.Join(c.bud.Dir, dir))
+	if err != nil {
+		return err
+	}
+	fsys, close, err := bud.FileSystem(ctx, log, module, c.Flag, c.in)
+	if err != nil {
+		return err
+	}
+	defer close()
+	ar := new(txtar.Archive)
 	err = fs.WalkDir(fsys, dir, func(path string, de fs.DirEntry, err error) error {
 		if err != nil {
 			return err
