@@ -6,14 +6,13 @@ import (
 	"go/build"
 	"io/fs"
 	"os"
+	"path"
 	"path/filepath"
 	"strings"
 	"testing"
 
-	"github.com/livebud/bud/internal/fscache"
 	"github.com/livebud/bud/internal/testdir"
 	"github.com/livebud/bud/package/gomod"
-	"github.com/livebud/bud/package/log/testlog"
 	"github.com/livebud/bud/package/modcache"
 	"github.com/livebud/bud/package/vfs"
 
@@ -153,10 +152,11 @@ func TestModuleFindStdlib(t *testing.T) {
 func TestFindNested(t *testing.T) {
 	is := is.New(t)
 	ctx := context.Background()
-	dir := t.TempDir()
+	dir, err := filepath.EvalSymlinks(t.TempDir())
+	is.NoErr(err)
 	td := testdir.New(dir)
-	td.Modules["github.com/livebud/bud-test-plugin"] = "v0.0.8"
-	err := td.Write(ctx)
+	td.Modules["github.com/livebud/bud-test-plugin"] = "v0.0.9"
+	err = td.Write(ctx)
 	is.NoErr(err)
 	modCache := modcache.Default()
 	module1, err := gomod.Find(dir)
@@ -170,7 +170,7 @@ func TestFindNested(t *testing.T) {
 	module2, err := module1.Find("github.com/livebud/bud-test-plugin")
 	is.NoErr(err)
 	is.Equal(module2.Import(), "github.com/livebud/bud-test-plugin")
-	is.Equal(module2.Directory(), modCache.Directory("github.com/livebud", "bud-test-plugin@v0.0.8"))
+	is.Equal(module2.Directory(), modCache.Directory("github.com/livebud", "bud-test-plugin@v0.0.9"))
 	data, err = fs.ReadFile(module2, "go.mod")
 	is.NoErr(err)
 	m2, err := gomod.Parse("go.mod", data)
@@ -190,13 +190,13 @@ func TestFindNested(t *testing.T) {
 	is.NoErr(err)
 	is.Equal(m3.Import(), "github.com/livebud/bud-test-nested-plugin")
 
-	// Ensure module1 is not overriden
+	// Ensure module1 is not overridden
 	is.Equal(module1.Import(), "app.com")
 	is.Equal(module1.Directory(), dir)
 
-	// Ensure module2 is not overriden
+	// Ensure module2 is not overridden
 	is.Equal(module2.Import(), "github.com/livebud/bud-test-plugin")
-	is.Equal(module2.Directory(), modCache.Directory("github.com/livebud", "bud-test-plugin@v0.0.8"))
+	is.Equal(module2.Directory(), modCache.Directory("github.com/livebud", "bud-test-plugin@v0.0.9"))
 }
 
 func TestOpen(t *testing.T) {
@@ -210,55 +210,6 @@ func TestOpen(t *testing.T) {
 	is.Equal(true, contains(des, "go.mod", "main.go"))
 }
 
-func TestFileCacheDir(t *testing.T) {
-	t.SkipNow()
-	log := testlog.New()
-	is := is.New(t)
-	appDir := t.TempDir()
-	err := vfs.Write(appDir, vfs.Map{
-		"go.mod":  []byte(`module app.com`),
-		"main.go": []byte(`package main`),
-	})
-	is.NoErr(err)
-	fmap := fscache.New(log)
-	module, err := gomod.Find(appDir, gomod.WithFSCache(fmap))
-	is.NoErr(err)
-	// Check initial
-	des, err := fs.ReadDir(module, ".")
-	is.NoErr(err)
-	is.Equal(2, len(des))
-	is.Equal("go.mod", des[0].Name())
-	is.Equal("main.go", des[1].Name())
-	// Delete a file and check again to ensure it's cached
-	err = os.RemoveAll(filepath.Join(appDir, "main.go"))
-	is.NoErr(err)
-	des, err = fs.ReadDir(module, ".")
-	is.NoErr(err)
-	is.Equal(2, len(des))
-	is.Equal("go.mod", des[0].Name())
-	is.Equal("main.go", des[1].Name())
-	// Delete from the cache to see that it's been updated
-	fmap.Delete("main.go")
-	des, err = fs.ReadDir(module, ".")
-	is.NoErr(err)
-	is.Equal(1, len(des))
-	is.Equal("go.mod", des[0].Name())
-	// Create a file and see stale dir
-	err = os.WriteFile(filepath.Join(appDir, "main.go"), []byte(`package main`), 0644)
-	is.NoErr(err)
-	des, err = fs.ReadDir(module, ".")
-	is.NoErr(err)
-	is.Equal(1, len(des))
-	is.Equal("go.mod", des[0].Name())
-	// Mark the cache as creating main.go and see that it's been updated
-	fmap.Create("main.go")
-	des, err = fs.ReadDir(module, ".")
-	is.NoErr(err)
-	is.Equal(2, len(des))
-	is.Equal("go.mod", des[0].Name())
-	is.Equal("main.go", des[1].Name())
-}
-
 func TestModuleFindLocal(t *testing.T) {
 	is := is.New(t)
 	wd, err := os.Getwd()
@@ -325,3 +276,24 @@ func TestMissingModule(t *testing.T) {
 	is.Equal(err.Error(), `mod: missing module statement in "go.mod", received "require github.com/evanw/esbuild v0.14.11\n"`)
 	is.Equal(module, nil)
 }
+
+func TestFindBy(t *testing.T) {
+	is := is.New(t)
+	ctx := context.Background()
+	dir, err := filepath.EvalSymlinks(t.TempDir())
+	is.NoErr(err)
+	td := testdir.New(dir)
+	td.Modules["github.com/livebud/bud-test-plugin"] = "v0.0.9"
+	td.Modules["github.com/livebud/bud-test-nested-plugin"] = "v0.0.5"
+	err = td.Write(ctx)
+	is.NoErr(err)
+	module, err := gomod.Find(dir)
+	is.NoErr(err)
+	modules, err := module.FindBy(func(mod *gomod.Require) bool {
+		return strings.HasPrefix(path.Base(mod.Mod.Path), "bud-")
+	})
+	is.NoErr(err)
+	is.Equal(len(modules), 2)
+	is.Equal(modules[0].Import(), "github.com/livebud/bud-test-nested-plugin")
+	is.Equal(modules[1].Import(), "github.com/livebud/bud-test-plugin")
+}
