@@ -7,6 +7,8 @@ package bud
 
 import (
 	_ "github.com/evanw/esbuild/cmd/esbuild"
+	_ "github.com/livebud/bud-test-plugin"
 	_ "github.com/pointlander/peg"
+	_ "honnef.co/go/tools/cmd/staticcheck"
 	_ "src.techknowlogick.com/xgo"
 )
